# (c) 2001 Nuxeo SARL <http://nuxeo.com>
# (c) 2001 Florent Guillaume <mailto:fg@nuxeo.com>
# See licence info at the end of this file.
# $Id: PortalContentFolder.py,v 1.3 2001/11/16 12:01:33 guillaum Exp $

"""
PortalContentFolder (for CMF) is a mix of both PortalContent and
SkinnedFolder, so that you can have a folder-like object that gets
catalogged and is subject to the workflow.
"""

__version__='$Revision: 1.3 $'[11:-2]

from AccessControl import ClassSecurityInfo
from Acquisition import aq_base
from Globals import InitializeClass #, DTMLFile

from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent

from Products.CMFCore.PortalFolder import PortalFolder
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl


def addPortalContentFolder(self, id, title='', REQUEST=None):
    """
    Adds a new PortalContentFolder.
    """
    ob = PortalContentFolder(id, title)
    self._setObject(id, ob)

    if REQUEST is not None:
        REQUEST.RESPONSE.redirect(self.absolute_url()+'/manage_main')


# addPortalContentFolderForm = DTMLFile('dtml/addPortalContentFolderForm', globals())


factory_type_information = (
    { 'id'             : 'PortalContentFolder',
      'meta_type'      : 'PortalContentFolder',
      'description'    :
      """A PortalContentFolder has content and behaves like a folder.""",
      'icon'           : '',
      'product'        : 'PortalContentFolder',
      'factory'        : 'addPortalContentFolder',
      'filter_content_types' : 0,
      'immediate_view' : 'folder_contents',
      'actions'        :
      ( { 'name'          : 'View',
          'action'        : 'folder_contents',
          'permissions'   : (View,),
          'category'      : 'object',
          },
        { 'name'          : 'Edit',
          'action'        : 'folder_edit_form',
          'permissions'   : (ModifyPortalContent,),
          },
        { 'name'          : 'Metadata',
          'action'        : 'metadata_edit_form',
          'permissions'   : (ModifyPortalContent,),
          },
        ),
      },
    )


class PortalContentFolder(PortalFolder, PortalContent, DefaultDublinCoreImpl):
    """
    Implements a PortalContentFolder, a PortalFolder with contentish
    methods so that it can belong to a workflow and be indexed.
    """

    meta_type = 'PortalContentFolder'
    portal_type = 'PortalContentFolder'

    manage_options = ( PortalFolder.manage_options[:3] +
                       ( { 'label'  : 'Dublin Core',
                           'action' : 'manage_metadata',
                           },
                         ) +
                       PortalFolder.manage_options[3:]
                       )

    def __init__(self, id, title=''):
        DefaultDublinCoreImpl.__init__(self)
        self.id = id
        self.title = title

    security = ClassSecurityInfo()

    #
    # Workflow interaction
    #

    security.declarePrivate('manage_afterAdd')
    def manage_afterAdd(self, item, container):
        " Add self to the workflow and catalog. "
        # Recurse in the children (ObjectManager)
        PortalFolder.manage_afterAdd(self, item, container)
        # Add self to workflow and catalog
        PortalContent.manage_afterAdd(self, item, container)
        
    security.declarePrivate('manage_beforeDelete')
    def manage_beforeDelete(self, item, container):
        " Remove self from the workflow and catalog. "
        # We don't call PortalContent.manage_beforeDelete because
        #  it deals with talkbacks which are subobjects...
        # Remove self from catalog
        if aq_base(container) is not aq_base(self):
            self.unindexObject()
        # Then recurse in the children (ObjectManager)
        PortalFolder.manage_beforeDelete(self, item, container)

InitializeClass(PortalContentFolder)


# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
